========
Tutorial
========

.. todo:: This documentation is incomplete -- pull requests are welcome!

* Install Python / virtualenv / Meteor
* Setup repo / add basics:
  - setup.py
  - django-admin.py startproject
  - meteor create <path>
  - letsencrypt
